SWDEV-249487-remove two HCC related APIs

Change-Id: Icf90ece0808643e0c5f0cc00b6644d5171b553d8
Šī revīzija ir iekļauta:
Julia Jiang
2020-09-28 20:13:28 -04:00
revīziju iesūtīja Julia Jiang
vecāks e0be2ca8dd
revīzija c2a3d19acb
9 mainīti faili ar 2 papildinājumiem un 204 dzēšanām
-21
Parādīt failu
@@ -1,21 +0,0 @@
/**
* @defgroup HipDb HCC-specific debug facilities
* @{
*/
/**
* @brief * Print memory tracker information for this pointer.
*
* HIP maintains a table for all memory allocations performed by the application.
* If targetAddress is 0, the entire table is printed to stderr.
* If targetAddress is non-null, this routine will perform some forensic analysis
* to find the pointer
*/
void hipdbPrintMem(void* targetAddress);
// doxygen end HipDb
/**
* @}
*/
+2 -25
Parādīt failu
@@ -1019,7 +1019,7 @@ hipError_t hipStreamAddCallback(hipStream_t stream, hipStreamCallback_t callback
* #hipEventDisableTiming : Disable recording of timing information. On ROCM platform, timing
information is always recorded and this flag has no performance benefit.
* @warning On HCC platform, hipEventInterprocess support is under development. Use of this flag
* @warning On AMD platform, hipEventInterprocess support is under development. Use of this flag
will return an error.
*
* @returns #hipSuccess, #hipErrorNotInitialized, #hipErrorInvalidValue,
@@ -1104,7 +1104,7 @@ hipError_t hipEventDestroy(hipEvent_t event);
*
* If hipEventRecord() has not been called on @p event, this function returns immediately.
*
* TODO-hcc - This function needs to support hipEventBlockingSync parameter.
* TODO-hip- This function needs to support hipEventBlockingSync parameter.
*
* @param[in] event Event on which to wait.
* @returns #hipSuccess, #hipErrorInvalidValue, #hipErrorNotInitialized,
@@ -4256,29 +4256,6 @@ static inline hipError_t hipUnbindTexture(
#pragma GCC visibility pop
#endif
/**
*-------------------------------------------------------------------------------------------------
*-------------------------------------------------------------------------------------------------
* @defgroup HCC_Specific HCC-Specific Accessors
* @{
*
* The following calls are only supported when compiler HIP with HCC.
* To produce portable code, use of these calls must be guarded #ifdef checks:
* @code
* #ifdef __HCC__
* hc::accelerator acc;
hipError_t err = hipHccGetAccelerator(deviceId, &acc)
* #endif
* @endcode
*
*/
// end-group HCC_Specific
/**
* @}
*/
// doxygen end HIP API
/**
* @}
-36
Parādīt failu
@@ -27,42 +27,6 @@ THE SOFTWARE.
#include <tuple>
#include <type_traits>
#endif
#ifdef __HCC__
// Forward declarations:
namespace hc {
class accelerator;
class accelerator_view;
}; // namespace hc
/**
*-------------------------------------------------------------------------------------------------
*-------------------------------------------------------------------------------------------------
* @defgroup HCC-specific features
* @warning These APIs provide access to special features of HCC compiler and are not available
*through the CUDA path.
* @{
*/
/**
* @brief Return hc::accelerator associated with the specified deviceId
* @return #hipSuccess, #hipErrorInvalidDevice
*/
HIP_PUBLIC_API
hipError_t hipHccGetAccelerator(int deviceId, hc::accelerator* acc);
/**
* @brief Return hc::accelerator_view associated with the specified stream
*
* If stream is 0, the accelerator_view for the default stream is returned.
* @return #hipSuccess
*/
HIP_PUBLIC_API
hipError_t hipHccGetAcceleratorView(hipStream_t stream, hc::accelerator_view** av);
#endif // #ifdef __HCC__
/**
* @brief launches kernel f with launch parameters and shared memory on stream with arguments passed